@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::Validation;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Validation vocabulary
 
-our $VERSION = '0.615';
+our $VERSION = '0.616';
 
 use 5.020;
 use Moo;
@@ -18,7 +18,8 @@ no if "$]" >= 5.033001, feature => 'multidimensional';
 no if "$]" >= 5.033006, feature => 'bareword_filehandles';
 no if "$]" >= 5.041009, feature => 'smartmatch';
 no feature 'switch';
-use List::Util 'any';
+use if "$]" < 5.041010, 'List::Util' => 'any';
+use if "$]" >= 5.041010, experimental => 'keyword_any';
 use Ref::Util 0.100 'is_plain_arrayref';
 use Scalar::Util 'looks_like_number';
 use JSON::Schema::Modern::Utilities qw(is_type get_type is_bignum is_equal is_elements_unique E assert_keyword_type assert_pattern jsonp sprintf_num);
@@ -67,22 +68,16 @@ sub _traverse_keyword_type ($class, $schema, $state) {
 
 sub _eval_keyword_type ($class, $data, $schema, $state) {
   my $type = get_type($data, $state->{spec_version} eq 'draft4' ? { legacy_ints => 1 } : ());
-  if (is_plain_arrayref($schema->{type})) {
-    return 1 if any {
-      $type eq $_ or ($_ eq 'number' and $type eq 'integer')
-        or ($type eq 'string' and $state->{stringy_numbers} and looks_like_number($data)
-            and ($_ eq 'number' or ($_ eq 'integer' and $data == int($data))))
-        or ($_ eq 'boolean' and $state->{scalarref_booleans} and $type eq 'reference to SCALAR')
-    } $schema->{type}->@*;
-    return E($state, 'got %s, not one of %s', $type, join(', ', $schema->{type}->@*));
-  }
-  else {
-    return 1 if $type eq $schema->{type} or ($schema->{type} eq 'number' and $type eq 'integer')
+  my @want = is_plain_arrayref($schema->{type}) ? $schema->{type}->@* : $schema->{type};
+
+  return 1 if any {
+    $type eq $_ or ($_ eq 'number' and $type eq 'integer')
       or ($type eq 'string' and $state->{stringy_numbers} and looks_like_number($data)
-          and ($schema->{type} eq 'number' or ($schema->{type} eq 'integer' and $data == int($data))))
-      or ($schema->{type} eq 'boolean' and $state->{scalarref_booleans} and $type eq 'reference to SCALAR');
-    return E($state, 'got %s, not %s', $type, $schema->{type});
-  }
+          and ($_ eq 'number' or ($_ eq 'integer' and $data == int($data))))
+      or ($_ eq 'boolean' and $state->{scalarref_booleans} and $type eq 'reference to SCALAR')
+  } @want;
+
+  return E($state, 'got %s, not %s%s', $type, (@want > 1 ? 'one of ' : ''), join(', ', @want));
 }
 
 sub _traverse_keyword_enum ($class, $schema, $state) {
@@ -364,7 +359,7 @@ JSON::Schema::Modern::Vocabulary::Validation - Implementation of the JSON Schema
 
 =head1 VERSION
 
-version 0.615
+version 0.616
 
 =head1 DESCRIPTION
 
